==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.default-high-contrast.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test default-high-contrast theme 1`] = `
Object {
  "lines": Array [
    "[48;2;0;0;0m [38;2;255;255;255m 1 │ [39m[38;2;255;255;255m{[39m                                                                         [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 2 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"name\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"test-package\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 3 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"description\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"Some[39m[38;2;124;124;124m·[39m[38;2;206;145;120museful[39m[38;2;124;124;124m·[39m[38;2;206;145;120mpackage[39m[38;2;124;124;124m·[39m[38;2;206;145;120mto[39m[38;2;124;124;124m·[39m[38;2;206;145;120mdo[39m[38;2;124;124;124m·[39m[38;2;206;145;120msome[39m[38;2;124;124;124m·[39m[38;2;206;145;120museful[39m[38;2;124;124;124m·[39m[38;2;206;145;120mstuff[39m[38;2;124;124;124m·[39m[38;2;206;145;120mwith[39m[38;2;124;124;124m·[39m[38;2;206;145;120madvanc[39m[38;2;206;145;120m…[39m[49m",
    "[48;2;0;0;0m [38;2;255;255;255m 4 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"version\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;255;255;255m,[39m                                                     [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 5 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"private\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;86;156;214mtrue[39m[38;2;255;255;255m,[39m                                                        [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 6 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"license\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"MIT\\"[39m[38;2;255;255;255m,[39m                                                       [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 7 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"dependencies\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;255;255;255m{[39m                                                       [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 8 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-1\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 9 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-2\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"2.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m10 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-3\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"3.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m11 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-4\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"4.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m12 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-5\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"5.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m13 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-6\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;0;0;0m [38;2;255;255;255m14 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;255;255;255m}[39m                                                                       [49m",
    "[48;2;0;0;0m [38;2;255;255;255m15 │ [39m[38;2;255;255;255m}[39m                                                                         [49m",
    "[48;2;0;0;0m [38;2;255;255;255m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #D4D4D4 │ \\"name\\"
 1 │  8, 9 │ ─────── │ :
 1 │ 10,24 │ #CE9178 │ \\"test-package\\"
 1 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  2,15 │ #D4D4D4 │ \\"description\\"
 2 │ 15,16 │ ─────── │ :
 2 │ 17,90 │ #CE9178 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  2,11 │ #D4D4D4 │ \\"version\\"
 3 │ 11,12 │ ─────── │ :
 3 │ 13,20 │ #CE9178 │ \\"1.0.0\\"
 3 │ 20,21 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  2,11 │ #D4D4D4 │ \\"private\\"
 4 │ 11,12 │ ─────── │ :
 4 │ 13,17 │ #569CD6 │ true
 4 │ 17,18 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2,11 │ #D4D4D4 │ \\"license\\"
 5 │ 11,12 │ ─────── │ :
 5 │ 13,18 │ #CE9178 │ \\"MIT\\"
 5 │ 18,19 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2,16 │ #D4D4D4 │ \\"dependencies\\"
 6 │ 16,17 │ ─────── │ :
 6 │ 18,19 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,15 │ #D4D4D4 │ \\"package-1\\"
 7 │ 15,16 │ ─────── │ :
 7 │ 17,24 │ #CE9178 │ \\"1.0.0\\"
 7 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  4,15 │ #D4D4D4 │ \\"package-2\\"
 8 │ 15,16 │ ─────── │ :
 8 │ 17,24 │ #CE9178 │ \\"2.0.0\\"
 8 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  4,15 │ #D4D4D4 │ \\"package-3\\"
 9 │ 15,16 │ ─────── │ :
 9 │ 17,24 │ #CE9178 │ \\"3.0.0\\"
 9 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  4,15 │ #D4D4D4 │ \\"package-4\\"
10 │ 15,16 │ ─────── │ :
10 │ 17,24 │ #CE9178 │ \\"4.0.0\\"
10 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  4,15 │ #D4D4D4 │ \\"package-5\\"
11 │ 15,16 │ ─────── │ :
11 │ 17,24 │ #CE9178 │ \\"5.0.0\\"
11 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  4,15 │ #D4D4D4 │ \\"package-6\\"
12 │ 15,16 │ ─────── │ :
12 │ 17,24 │ #CE9178 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  2, 3 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.default-high-contrast.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test default-high-contrast theme 1`] = `
Object {
  "lines": Array [
    "[48;2;0;0;0m [38;2;255;255;255m 1 │ [39m[38;2;255;255;255m{[39m                                                                         [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 2 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"name\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"test-package\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 3 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"description\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"Some[39m[38;2;124;124;124m·[39m[38;2;206;145;120museful[39m[38;2;124;124;124m·[39m[38;2;206;145;120mpackage[39m[38;2;124;124;124m·[39m[38;2;206;145;120mto[39m[38;2;124;124;124m·[39m[38;2;206;145;120mdo[39m[38;2;124;124;124m·[39m[38;2;206;145;120msome[39m[38;2;124;124;124m·[39m[38;2;206;145;120museful[39m[38;2;124;124;124m·[39m[38;2;206;145;120mstuff[39m[38;2;124;124;124m·[39m[38;2;206;145;120mwith[39m[38;2;124;124;124m·[39m[38;2;206;145;120madvanc…[39m[49m",
    "[48;2;0;0;0m [38;2;255;255;255m 4 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"version\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;255;255;255m,[39m                                                     [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 5 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"private\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;86;156;214mtrue[39m[38;2;255;255;255m,[39m                                                        [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 6 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"license\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"MIT\\"[39m[38;2;255;255;255m,[39m                                                       [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 7 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"dependencies\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;255;255;255m{[39m                                                       [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 8 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-1\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m 9 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-2\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"2.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m10 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-3\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"3.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m11 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-4\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"4.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m12 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-5\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"5.0.0\\"[39m[38;2;255;255;255m,[39m                                                 [49m",
    "[48;2;0;0;0m [38;2;255;255;255m13 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;212;212;212m\\"package-6\\"[39m[38;2;255;255;255m:[39m[38;2;124;124;124m·[39m[38;2;206;145;120m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;0;0;0m [38;2;255;255;255m14 │ [39m[38;2;124;124;124m·[39m[38;2;124;124;124m·[39m[38;2;255;255;255m}[39m                                                                       [49m",
    "[48;2;0;0;0m [38;2;255;255;255m15 │ [39m[38;2;255;255;255m}[39m                                                                         [49m",
    "[48;2;0;0;0m [38;2;255;255;255m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #D4D4D4 │ \\"name\\"
 1 │  8, 9 │ ─────── │ :
 1 │ 10,24 │ #CE9178 │ \\"test-package\\"
 1 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  2,15 │ #D4D4D4 │ \\"description\\"
 2 │ 15,16 │ ─────── │ :
 2 │ 17,90 │ #CE9178 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  2,11 │ #D4D4D4 │ \\"version\\"
 3 │ 11,12 │ ─────── │ :
 3 │ 13,20 │ #CE9178 │ \\"1.0.0\\"
 3 │ 20,21 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  2,11 │ #D4D4D4 │ \\"private\\"
 4 │ 11,12 │ ─────── │ :
 4 │ 13,17 │ #569CD6 │ true
 4 │ 17,18 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2,11 │ #D4D4D4 │ \\"license\\"
 5 │ 11,12 │ ─────── │ :
 5 │ 13,18 │ #CE9178 │ \\"MIT\\"
 5 │ 18,19 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2,16 │ #D4D4D4 │ \\"dependencies\\"
 6 │ 16,17 │ ─────── │ :
 6 │ 18,19 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,15 │ #D4D4D4 │ \\"package-1\\"
 7 │ 15,16 │ ─────── │ :
 7 │ 17,24 │ #CE9178 │ \\"1.0.0\\"
 7 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  4,15 │ #D4D4D4 │ \\"package-2\\"
 8 │ 15,16 │ ─────── │ :
 8 │ 17,24 │ #CE9178 │ \\"2.0.0\\"
 8 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  4,15 │ #D4D4D4 │ \\"package-3\\"
 9 │ 15,16 │ ─────── │ :
 9 │ 17,24 │ #CE9178 │ \\"3.0.0\\"
 9 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  4,15 │ #D4D4D4 │ \\"package-4\\"
10 │ 15,16 │ ─────── │ :
10 │ 17,24 │ #CE9178 │ \\"4.0.0\\"
10 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  4,15 │ #D4D4D4 │ \\"package-5\\"
11 │ 15,16 │ ─────── │ :
11 │ 17,24 │ #CE9178 │ \\"5.0.0\\"
11 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  4,15 │ #D4D4D4 │ \\"package-6\\"
12 │ 15,16 │ ─────── │ :
12 │ 17,24 │ #CE9178 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  2, 3 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
